==> forge2d-0.6.5.tar.gz: lib/src/common/viewport_transform.dart <==
part of forge2d.common;

class ViewportTransform {
  ViewportTransform(Vector2 e, Vector2 c, this.scale)
      : extents = Vector2.copy(e),
        center = Vector2.copy(c);

  /// if we flip the y axis when transforming.
  bool yFlip = false;

  /// This is the half-width and half-height.
  /// This should be the actual half-width and
  /// half-height, not anything transformed or scaled.
  Vector2 extents;

  /// Returns the scaling factor used in converting from world sizes to rendering
  /// sizes.
  double scale;

  /// center of the viewport.
  Vector2 center;

  /// Sets the transform's center to the given x and y coordinates,
  /// and using the given scale.
  void setCamera(double x, double y, double s) {
    center.setValues(x, y);
    scale = s;
  }

  /// The current translation is the difference in canvas units between the
  /// actual center of the canvas and the currently specified center. For
  /// example, if the actual canvas center is (5, 5) but the current center is
  /// (6, 6), the translation is (1, 1).
  Vector2 get translation => (extents - center)..y *= (yFlip ? -1 : 1);

  set translation(Vector2 translation) {
    center.setFrom(extents);
    center.sub(translation);
  }

  /// Takes the world coordinates and return the corresponding screen coordinates
  Vector2 getWorldToScreen(Vector2 argWorld) {
    // Correct for canvas considering the upper-left corner, rather than the
    // center, to be the origin.
    final double gridCorrectedX = (argWorld.x * scale) + extents.x;
    final double gridCorrectedY = extents.y - (argWorld.y * scale);
    return Vector2(
      gridCorrectedX + translation.x,
      gridCorrectedY + -translation.y,
    );
  }

  /// Takes the screen coordinates and return the corresponding world coordinates
  Vector2 getScreenToWorld(Vector2 argScreen) {
    final double translationCorrectedX = argScreen.x - translation.x;
    final double translationCorrectedY = argScreen.y + translation.y;
    final double gridCorrectedX = (translationCorrectedX - extents.x) / scale;
    final double gridCorrectedY =
        ((translationCorrectedY - extents.y) * -1) / scale;
    return Vector2(gridCorrectedX, gridCorrectedY);
  }
}

==> forge2d-0.7.0.tar.gz: lib/src/common/viewport_transform.dart <==
import '../../forge2d.dart';

class ViewportTransform {
  ViewportTransform(Vector2 e, Vector2 c, this.scale)
      : extents = Vector2.copy(e),
        center = Vector2.copy(c);

  /// if we flip the y axis when transforming.
  bool yFlip = false;

  /// This is the half-width and half-height.
  /// This should be the actual half-width and
  /// half-height, not anything transformed or scaled.
  Vector2 extents;

  /// Returns the scaling factor used in converting from world sizes to rendering
  /// sizes.
  double scale;

  /// center of the viewport.
  Vector2 center;

  /// Sets the transform's center to the given x and y coordinates,
  /// and using the given scale.
  void setCamera(double x, double y, double s) {
    center.setValues(x, y);
    scale = s;
  }

  /// The current translation is the difference in canvas units between the
  /// actual center of the canvas and the currently specified center. For
  /// example, if the actual canvas center is (5, 5) but the current center is
  /// (6, 6), the translation is (1, 1).
  Vector2 get translation => extents - center;

  set translation(Vector2 translation) {
    center.setFrom(extents);
    center.sub(translation);
  }

  /// Takes the world coordinates and return the corresponding screen coordinates
  Vector2 worldToScreen(Vector2 argWorld) {
    // Correct for canvas considering the upper-left corner, rather than the
    // center, to be the origin.
    final gridCorrected = Vector2(
      (argWorld.x * scale) + extents.x,
      extents.y - (argWorld.y * scale),
    );
    return gridCorrected + (translation..y *= (yFlip ? 1 : -1));
  }

  /// Takes the screen coordinates and return the corresponding world coordinates
  Vector2 screenToWorld(Vector2 argScreen) {
    final translatedCorrected =
        argScreen - (translation..y *= (yFlip ? 1 : -1));
    return ((translatedCorrected - extents)..y *= -1) / scale;
  }
}
